@@ -1,6 +1,6 @@
 use super::{
-    deep_map, deep_map_op_context_preorder_stoppable, deep_map_preorder, deep_map_unwrap,
-    deep_map_unwrap_preorder, prelude::*, visit_circuit, visit_circuit_fallable, HashBytes,
+    deep_map, deep_map_op_context_preorder_stoppable, deep_map_preorder, deep_map_unwrap_preorder,
+    prelude::*, visit_circuit, visit_circuit_fallable, HashBytes,
 };
 use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::pycall;
