@@ -1,13 +1,15 @@
 use crate::{
     all_imports::Shape,
-    circuit::{circuit_utils::has_leaf_symbols, repr::RustRepr},
+    circuit::{print::repr_circuit_deep_compiler, repr::RustRepr},
     hashmaps::FxHashMap as HashMap,
 };
+use std::io::prelude::*;
 
 use num_bigint::BigUint;
 
 use super::{
     canonicalize::deep_canonicalize,
+    circuit_utils::has_leaf_symbols,
     compiler_heuristics::deep_maybe_distribute,
     compiler_strip::strip_names,
     debugging::{create_circuit_test, randn_ablate_great_grandchildren},
@@ -67,6 +69,8 @@ pub struct OptimizationSettings {
     pub log_simplifications: bool,
     #[pyo3(get, set)]
     pub log_slow_einsums: bool,
+    #[pyo3(get, set)]
+    pub save_circ: bool,
 }
 
 #[cfg(not(feature = "real-pyo3"))]
@@ -96,6 +100,7 @@ impl Default for OptimizationSettings {
             create_tests: false,
             log_simplifications: false,
             log_slow_einsums: false,
+            save_circ: false,
         }
     }
 }
@@ -120,7 +125,8 @@ impl OptimizationSettings {
         capture_and_print = "OptimizationSettings::default().capture_and_print",
         create_tests = "OptimizationSettings::default().create_tests",
         log_simplifications = "OptimizationSettings::default().log_simplifications",
-        log_slow_einsums = "OptimizationSettings::default().log_slow_einsums"
+        log_slow_einsums = "OptimizationSettings::default().log_slow_einsums",
+        save_circ = "OptimizationSettings::default().save_circ"
     )]
     fn new(
         verbose: usize,
@@ -140,6 +146,7 @@ impl OptimizationSettings {
         create_tests: bool,
         log_simplifications: bool,
         log_slow_einsums: bool,
+        save_circ: bool,
     ) -> Self {
         Self {
             verbose,
@@ -159,6 +166,7 @@ impl OptimizationSettings {
             create_tests,
             log_simplifications,
             log_slow_einsums,
+            save_circ,
         }
     }
 }
@@ -236,12 +244,24 @@ pub fn optimize_circuit_py(circuit: CircuitRc, settings: OptimizationSettings) -
 pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -> CircuitRc {
     let print_timings = context.settings.verbose >= 2;
     let circuit = timed!(strip_names(circuit, context), 10, print_timings);
-    let circuit = timed!(deep_optimize_module_specs(circuit, context));
+    let circuit = timed!(
+        deep_optimize_module_specs(circuit, context),
+        10,
+        print_timings
+    );
     let circuit = timed!(deep_canonicalize(circuit, context), 10, print_timings);
     if context.settings.verbose >= 4 {
         println!("Original Circuit");
         circuit.compiler_print();
     }
+    if context.settings.save_circ {
+        let s = repr_circuit_deep_compiler(&circuit, true, true);
+        let f_name = format!("cached_circ_{}.circ", circuit.info().hash_usize());
+        println!("Save circ to {}", f_name);
+
+        let mut file = std::fs::File::create(f_name).unwrap();
+        file.write_all(s.as_bytes()).unwrap();
+    }
     if context.settings.create_tests {
         // Make compiler_simp tests here
         let ablated = randn_ablate_great_grandchildren(circuit.clone());
@@ -279,7 +299,7 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
     );
 
     let circuit = timed!(deep_canonicalize(circuit, context), 10, print_timings);
-    if context.settings.verbose >= 2 {
+    if context.settings.verbose >= 3 {
         println!("Distributed Circuit");
         circuit.compiler_print();
     }
