@@ -10,9 +10,8 @@ use crate::{
 use num_bigint::BigUint;
 
 use super::{
-    apply_fn_cache, deep_map_op_pre_new_children, deep_map_unwrap, parse_compiler_repr_bijection,
-    visit_circuit, visit_circuit_fallable, visit_circuit_with_parents, ArrayConstant, Circuit,
-    CircuitConstructionError, CircuitNode, CircuitRc, HashBytes, Index,
+    apply_fn_cache, deep_map_op_pre_new_children, deep_map_unwrap, visit_circuit, ArrayConstant,
+    Circuit, CircuitNode, CircuitRc, HashBytes, Index,
 };
 use crate::tensor_util::TorchDeviceDtype;
 use std::hash::Hash;
