@@ -1,10 +1,6 @@
 use super::circuit_optimizer::OptimizationContext;
-use super::{
-    deep_map_op_context, deep_map_unwrap, visit_circuit, Circuit, CircuitNode, CircuitRc,
-    HashBytes, ModuleNodeArgSpec,
-};
-use crate::circuit::{ModuleNode, ModuleNodeSpec};
-use crate::hashmaps::FxHashMap as HashMap;
+use super::{deep_map_op_context, Circuit, CircuitNode, CircuitRc};
+
 use crate::pyo3_prelude::*;
 
 /// don't change symbols bc their names matter for correctness
@@ -14,7 +10,7 @@ pub fn strip_names_py(circuit: CircuitRc) -> CircuitRc {
     strip_names(circuit, &mut Default::default())
 }
 pub fn strip_names(circuit: CircuitRc, context: &mut OptimizationContext) -> CircuitRc {
-    let result = deep_map_op_context(
+    deep_map_op_context(
         &circuit,
         &|circuit, _| match circuit {
             Circuit::Symbol(_sym) => None,
@@ -23,6 +19,5 @@ pub fn strip_names(circuit: CircuitRc, context: &mut OptimizationContext) -> Cir
         &mut (),
         &mut context.cache.stripped_names,
     )
-    .unwrap_or(circuit);
-    result
+    .unwrap_or(circuit)
 }
