@@ -1,5 +1,5 @@
 use crate::hashmaps::FxHashMap as HashMap;
-use crate::rrfs::{arrayconstant_from_hash, save_tensor_rrfs};
+use crate::rrfs::{arrayconstant_from_hash, arrayconstant_from_hash_prefix, save_tensor_rrfs};
 use crate::{new_rc, pyo3_prelude::*, sv};
 use base16::encode_lower;
 use macro_rules_attribute::apply;
@@ -191,6 +191,11 @@ impl ArrayConstant {
     pub fn from_hash(name: Option<String>, hash_base16: &str) -> Result<Self, PyErr> {
         arrayconstant_from_hash(name, hash_base16)
     }
+
+    #[staticmethod]
+    pub fn from_hash_prefix(name: Option<String>, hash_base16: &str) -> Result<Self, PyErr> {
+        arrayconstant_from_hash_prefix(name, hash_base16)
+    }
 }
 
 #[pyclass(extends=PyCircuitBase, unsendable)]
