@@ -103,6 +103,7 @@ pub fn compiler_simp_step(
                 l_wrap!(einsum_pull_removable_axes),
                 l_wrap!(einsum_pull_scatter),
                 f_wrap!(&einsum_push_down_trace),
+                f_wrap!(&einsum_concat_to_add),
             ];
             simp(node, fns, context)
         }
@@ -354,8 +355,7 @@ pub fn deep_pull_concat(circuit: CircuitRc, min_size: Option<usize>) -> CircuitR
     let mut cache = Default::default();
     let pulled = deep_pull_concat_messy(circuit, min_size);
     apply_fn_until_same(&pulled, |x: &CircuitRc| {
-        let result = deep_push_down_index(compiler_simp(x, &mut cache), min_size);
-        result
+        deep_push_down_index(compiler_simp(x, &mut cache), min_size)
     })
 }
 
@@ -367,7 +367,7 @@ pub fn deep_optimize_einsums_py(circ: CircuitRc) -> CircuitRc {
 
 pub fn deep_optimize_einsums(circ: CircuitRc, context: &mut OptimizationContext) -> CircuitRc {
     deep_map_op_context(
-        &**circ,
+        &circ,
         &|x: &Circuit, context: &mut OptimizationContext| match x {
             Circuit::Einsum(ein) => {
                 let (result, took) = timed_value!(einsum_nest_optimize(ein, context));
