@@ -786,6 +786,8 @@ pub enum CircuitConstructionError {
     EinsumOutputNotSubset {
         // TODO: args
     },
+    #[error("Einsum string invalid {string} {substring}")]
+    EinsumStringInvalid { string: String, substring: String },
 
     #[error("Sum nodes not broadcastable, {shapes:?}")]
     SumNotBroadcastable { shapes: Vec<Shape> },
