@@ -1,25 +1,19 @@
 use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::util::is_unique;
 use std::collections::BTreeMap;
-use std::iter::zip;
 
-use macro_rules_attribute::apply;
 use uuid::Uuid;
 
-use super::algebraic_rewrite::get_removable_axes;
 use super::circuit_node_private::CircuitNodePrivate;
 use super::circuit_utils::deep_map_pass_down_branching;
-use super::{
-    deep_map_unwrap, prelude::*, visit_circuit_with_parents_fallible, HashBytes, NamedAxes,
-};
-use super::{visit_circuit, visit_circuit_with_parents};
-use crate::cached_lambda;
+use super::{deep_map_unwrap, prelude::*, visit_circuit_with_parents_fallible, NamedAxes};
+
 use crate::pyo3_prelude::*;
 
 pub fn set_named_axes<T: CircuitNode + Clone>(node: &T, named_axes: NamedAxes) -> T {
     let mut result: T = node.clone();
     result.info_mut().named_axes = named_axes.clone();
-    let mut result = result.init_info().unwrap();
+    let result = result.init_info().unwrap();
     assert!(result.info().named_axes == named_axes);
     result
 }
@@ -77,15 +71,14 @@ pub fn propagate_named_axes(
                     .map(|_c| Default::default())
                     .collect::<Vec<NamedAxes>>()
             } else {
-                let new_child_axes = named_axes_backward(&**circuit, &{ axes.clone() });
-                new_child_axes
+                named_axes_backward(&**circuit, &{ axes.clone() })
             };
             child_axis_names
         },
         |circuit, named_axes, children| {
             set_named_axes(
                 &circuit.map_children_unwrap_idxs(|i| children[i].clone()),
-                merge_named_axes(&circuit.info().named_axes, &named_axes),
+                merge_named_axes(&circuit.info().named_axes, named_axes),
             )
             .rc()
         },
@@ -107,7 +100,7 @@ pub fn axis_of_name(circuit: &Circuit, name: &str) -> Option<usize> {
 pub fn get_axis_leaves(
     circuit: CircuitRc,
     axis: usize,
-    error_on_removable_axis_leaf: bool,
+    _error_on_removable_axis_leaf: bool,
 ) -> Result<
     (
         String,
@@ -132,19 +125,16 @@ pub fn get_axis_leaves(
         return Ok((
             name,
             circuit.clone(),
-            HashMap::from([(circuit.clone(), axis)]),
+            HashMap::from([(circuit, axis)]),
             HashSet::new(),
         ));
     }
-    let circ_named_axes = propagate_named_axes(
-        circuit.clone(),
-        BTreeMap::from([(axis as u8, name.clone())]),
-        true,
-    );
+    let circ_named_axes =
+        propagate_named_axes(circuit, BTreeMap::from([(axis as u8, name.clone())]), true);
     // circ_named_axes.compiler_print();
     let mut result_axis: HashMap<CircuitRc, usize> = Default::default();
     let mut result_no_axis: HashSet<CircuitRc> = Default::default();
-    let names_to_remove = Some(HashSet::from([name.clone()]));
+    let _names_to_remove = Some(HashSet::from([name.clone()]));
     visit_circuit_with_parents_fallible(&circ_named_axes, |x, parents| {
         // println!("child");
         // x.compiler_print();
@@ -163,7 +153,7 @@ pub fn get_axis_leaves(
         if axis_of_name(x, &name).is_none()
             && parents
                 .iter()
-                .any(|child| axis_of_name(&child, &name).is_some())
+                .any(|child| axis_of_name(child, &name).is_some())
         {
             result_no_axis.insert(x.clone().rc());
         }
@@ -180,7 +170,7 @@ pub fn deep_strip_axis_names(circuit: &Circuit, names: &Option<HashSet<String>>)
                 .named_axes
                 .clone()
                 .into_iter()
-                .filter(|(i, name)| !blacklist.contains(name))
+                .filter(|(_i, name)| !blacklist.contains(name))
                 .collect()
         } else {
             BTreeMap::new()
