@@ -53,7 +53,10 @@ pub fn repr_circuit_deep_compiler(
         if !shape_only_necessary
             || matches!(
                 circ,
-                Circuit::ScalarConstant(_) | Circuit::Scatter(_) | Circuit::Symbol(_)
+                Circuit::ScalarConstant(_)
+                    | Circuit::Scatter(_)
+                    | Circuit::Symbol(_)
+                    | Circuit::ArrayConstant(_)
             )
         {
             result.push_str(&format!(" {:?}", circ.info().shape));
@@ -293,9 +296,6 @@ pub fn repr_circuit_one_level(
                 repr_op_string(&mn.name_cloned())
             )
         }
-        _ => {
-            unimplemented!()
-        }
     }
 }
 
