@@ -1,5 +1,6 @@
 # this file is included with `include_str!()` in py_types.rs
 
+import atexit
 import functools
 import hashlib
 from typing import Tuple
@@ -11,8 +12,14 @@ PER_BLOCK_THREAD_COUNT = 128
 
 @functools.lru_cache(maxsize=None)
 def get_cuda_kernels():
+    import pycuda.autoprimaryctx as apc
+
+    ctx = apc.context
+    atexit.unregister(apc._finish_up)
+
+    import pycuda.cuda as cuda
+
     import pycuda.driver as cuda  # type: ignore
-    import pycuda.autoinit  # type: ignore
     from pycuda.compiler import SourceModule  # type: ignore
 
     # cuda hash by Peter Schmidt-Nielsen
@@ -90,7 +97,7 @@ def get_cuda_kernels():
 
     _gpuhash = mod.get_function("_gpuhash")
     _gpuhash_finalize = mod.get_function("_gpuhash_finalize")
-    return (_gpuhash, _gpuhash_finalize)
+    return (_gpuhash, _gpuhash_finalize, ctx)
 
 
 dtypes_to_bytes = {
@@ -124,20 +131,30 @@ def hash_tensor(tensor):
         m.update(tensor.detach().numpy().tobytes())  # this copies, could be optimized more
     else:
         # m.update(tensor.detach().cpu().numpy().tobytes())
-        m.update(tensor.detach().cpu().numpy().tobytes())
-        # try:
-        #     # hash function may be corrupting gpu
-        #     m.update(hash_tensor_contents_gpu(tensor))
-        #     print("gpu hashed")
-        # except Exception as e:
-        #     print("gpu hashing failed, maybe because cuda version < 11.4 or pycuda not installed")
-        #     print(e)
-        #     m.update(tensor.detach().cpu().numpy().tobytes())
+        try:
+            raise NotImplementedError(
+                "GPU hashing causes PyCUDA ERROR: The context stack was not empty upon module cleanup. stupid error on program exit "
+            )
+            # hash function may be corrupting gpu
+            m.update(hash_tensor_contents_gpu(tensor))
+            # print("gpu hashed")
+        except Exception as e:
+            print("gpu hashing failed, maybe because cuda version < 11.4 or pycuda not installed")
+            print(e)
+            m.update(tensor.detach().cpu().numpy().tobytes())
 
     return m.digest()[:32]
 
 
+def pop_cuda_context():
+    _, _, ctx = get_cuda_kernels()
+    ctx.pop()
+
+
 def hash_tensor_contents_gpu(tensor):
+    # this makes pycuda use the default context, whereas the
+    # default pycuda.autoinit uses a new context which clashes with pytorch
+
     tensor = tensor.contiguous()
     data_length = tensor.element_size() * tensor.nelement()
     block_count = 32
@@ -148,7 +165,7 @@ def hash_tensor_contents_gpu(tensor):
     if data_length > 1e8:
         block_count = 256
     block_hash_buffer = torch.zeros(size=(block_count * 8,), dtype=torch.int32, device=tensor.device)
-    _gpuhash, _gpuhash_finalize = get_cuda_kernels()
+    _gpuhash, _gpuhash_finalize, _ = get_cuda_kernels()
     _gpuhash(
         tensor,
         np.int64(data_length),
